@@ -4,7 +4,7 @@ import math
 class Tag(object):
     " Model representation of an RFID Tag. "
     def __init__(self, epc_id, frequency=None, slot=None, imag=None,
-                 qmag=None, iq_decoded=None, timestamp=None):
+                 qmag=None, iq_decoded=None, timestamp=None, id_prefix=None):
         self.epc_id = epc_id
         self.frequency = frequency and int(frequency) or None
         self.slot = slot and int(slot, 16) or None
@@ -12,6 +12,7 @@ class Tag(object):
         self.q_magnitude = qmag and int(qmag, 16) or 0
         self.iq_decoded = iq_decoded
         self.timestamp = timestamp and int(timestamp, 16) or None
+        self.trunc_id = id_prefix and epc_id.replace(id_prefix, '') or epc_id
 
     @property
     def signal_strength(self):
